@@ -1,9 +1,8 @@
 from .lightning import LightningRpc, RpcError, Millisatoshi
 from .plugin import Plugin, monkey_patch, RpcException
+from .gossmap import Gossmap, GossmapNode, GossmapChannel, GossmapNodeId
 
-
-__version__ = "0.10.1"
-
+__version__ = "0.10.2"
 
 __all__ = [
     "LightningRpc",
@@ -12,5 +11,9 @@ __all__ = [
     "RpcException",
     "Millisatoshi",
     "__version__",
-    "monkey_patch"
+    "monkey_patch",
+    "Gossmap",
+    "GossmapNode",
+    "GossmapChannel",
+    "GossmapNodeId",
 ]
